@@ -1,4 +1,6 @@
 from . import rand_util
 from . import spectral_fitters
 from . import util
+from . import Autoencoders
+from . import viz
 
