@@ -1,4 +1,5 @@
-from torch.utils.data import Dataset,
+from torch.utils.data import Dataset, DataLoader
+import numpy as np
 
 def get_n_params(model):
     '''
@@ -35,8 +36,11 @@ class Dataset_Generator(Dataset):
         self.sd = kwargs.get('sd')
         self.mean = kwargs.get('mean')
         self.amp = kwargs.get('amp')
+        self.fraction = kwargs.get('fraction')
         self.x_vector = kwargs.get('x_vector')
         self.size = size
+        self.noise = kwargs.get('noise')
+        self.verbose = kwargs.get('verbose')
         self.function = self.model(self.x_vector,
                                    sd=self.sd,
                                    mean=self.mean,
@@ -49,4 +53,10 @@ class Dataset_Generator(Dataset):
     def __getitem__(self, idx):
         input, params = self.function.sampler(device='cuda')
 
-        return {'input': input, 'params': params}
\ No newline at end of file
+        if self.noise is not None:
+            if self.verbose is True and not None:
+                print("adding noise\n")
+            input += np.random.uniform(0, self.noise, size=input.shape)
+            
+        return {'input': input, 'params': params}
+
